* Patch by Pierre Aubert, 26 Feb 2004
  add IDE support for MPC5200

* Patch by Masami Komiya, 26 Feb 2004:
  add autoload via NFS

* Patch by Stephen Williams
  Use of CONFIG_SERIAL_SOFTWARE_FIFO in board.c consistent with uses
  elsewhere in the source.
diff --git a/net/bootp.c b/net/bootp.c
index 854ca16..e02372c 100644
--- a/net/bootp.c
+++ b/net/bootp.c
@@ -331,13 +331,21 @@
 
 	debug ("Got good BOOTP\n");
 
-	if (((s = getenv("autoload")) != NULL) && (*s == 'n')) {
-		/*
-		 * Just use BOOTP to configure system;
-		 * Do not use TFTP to load the bootfile.
-		 */
-		NetState = NETLOOP_SUCCESS;
-		return;
+	if ((s = getenv("autoload")) != NULL) {
+		if (*s == 'n') {
+			/*
+			 * Just use BOOTP to configure system;
+			 * Do not use TFTP to load the bootfile.
+			 */
+			NetState = NETLOOP_SUCCESS;
+			return;
+		} else if (strcmp(s, "NFS") == 0) {
+			/*
+			 * Use NFS to load the bootfile.
+			 */
+			NfsStart();
+			return;
+		}
 	}
 
 	TftpStart();
@@ -881,9 +889,21 @@
 			printf("\n");
 
 			/* Obey the 'autoload' setting */
-			if (((s = getenv("autoload")) != NULL) && (*s == 'n')) {
-				NetState = NETLOOP_SUCCESS;
-				return;
+			if ((s = getenv("autoload")) != NULL) {
+				if (*s == 'n') {
+					/*
+					 * Just use BOOTP to configure system;
+					 * Do not use TFTP to load the bootfile.
+					 */
+					NetState = NETLOOP_SUCCESS;
+					return;
+				} else if (strcmp(s, "NFS") == 0) {
+					/*
+					 * Use NFS to load the bootfile.
+					 */
+					NfsStart();
+					return;
+				}
 			}
 			TftpStart();
 			return;